<?php

/**
  ReduxFramework Sample Config File
  For full documentation, please visit: https://docs.reduxframework.com
 * */

if (!class_exists('FastWP_Redux_Framework_config')) {

    class FastWP_Redux_Framework_config {

        public $args        = array();
        public $sections    = array();
        public $theme;
        public $ReduxFramework;

        public function __construct() {

            if (!class_exists('ReduxFramework')) {
                return;
            }

            $this->initSettings();

        }

        public function initSettings() {

            // Just for demo purposes. Not needed per say.
            $this->theme = wp_get_theme();

            // Set the default arguments
            $this->setArguments();


            // Create the sections and fields
            $this->setSections();

            if (!isset($this->args['opt_name'])) { // No errors please
                return;
            }

            // If Redux is running as a plugin, this will remove the demo notice and links
            //add_action( 'redux/loaded', array( $this, 'remove_demo' ) );

            // Function to test the compiler hook and demo CSS output.
            // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
            //add_filter('redux/options/'.$this->args['opt_name'].'/compiler', array( $this, 'compiler_action' ), 10, 2);

            // Change the arguments after they've been declared, but before the panel is created
            //add_filter('redux/options/'.$this->args['opt_name'].'/args', array( $this, 'change_arguments' ) );

            // Change the default value of a field after it's been set, but before it's been useds
            //add_filter('redux/options/'.$this->args['opt_name'].'/defaults', array( $this,'change_defaults' ) );

            // Dynamically add a section. Can be also used to modify sections/fields
            // add_filter('redux/options/' . $this->args['opt_name'] . '/sections', array($this, 'dynamic_section'));

            $this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
        }

        /**

          This is a test function that will let you see when the compiler hook occurs.
          It only runs if a field   set with compiler=>true is changed.

         * */
        function compiler_action($options, $css) {

        }

        /**

          Custom function for filtering the sections array. Good for child themes to override or add to the sections.
          Simply include this function in the child themes functions.php file.

          NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
          so you must use get_template_directory_uri() if you want to use any of the built in icons

         * */
        function dynamic_section($sections) {
            //$sections = array();
            /*$sections[] = array(
                'title' => esc_html__( 'Section via hook', 'conrad' ),
                'desc' => esc_html__( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'conrad' ),
                'icon' => 'el-icon-paper-clip',
                'fields' => array()
            );*/

            return $sections;
        }

        /**

          Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.

         * */
        function change_arguments($args) {
            //$args['dev_mode'] = true;

            return $args;
        }

        /**

          Filter hook for filtering the default value of any given field. Very useful in development mode.

         * */
        function change_defaults($defaults) {
         //   $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }

        public function setSections() {


            $this->sections[] = array(
                'icon'      => 'el-icon-wrench',
                'title'     => esc_html__( 'General', 'conrad' ),
                'fields'    => array(

                    array(
                        'id'        => 'opt-info-field',
                        'type'      => 'info',
                        'title'  => esc_html__( 'Welcome to Conrad Options Panel.', 'conrad' ),
                        'desc'      => esc_html__( 'It is meant to make your life easier by offering you options which will customize your website. Here you can set all general options that affects entire website.', 'conrad' )
                    ),

                    array(
                        'id'        => 'custom_css',
                        'type'      => 'textarea',
                        'title'     => esc_html__( 'Custom CSS', 'conrad' ),
                        'subtitle'  => esc_html__( 'Quickly add some CSS to your theme by adding it to this block.', 'conrad' ),
                        'validate'  => 'css',
                    ),
                    array(
                        'id'        => 'info_bubble_1_text',
                        'type'      => 'editor',
                        'title'     => esc_html__( 'Info bubble #1 content', 'conrad' ),
                        'subtitle'  => esc_html__( 'Place here your info bubble content.', 'conrad' ),
                        'required'  => array('use_info_bubble_1', '=', '1'),
                    ),
                    array(
                        'id'        => 'custom_js',
                        'type'      => 'ace_editor',
                        'title'     => esc_html__( 'Custom JS', 'conrad' ),
                        'subtitle'  => esc_html__( 'Paste your JavaScript code here. Use this field to quickly add JS code snippets.', 'conrad' ),
                        'mode'      => 'javascript',
                        'theme'     => 'chrome',
                        'default'   => ""
                    ),
                    array(
                        'id'        => 'font_lato',
                        'type'      => 'typography',
                        'title'     => esc_html__( 'Replace Lato font with this one:', 'conrad' ),
                        'subtitle'  => esc_html__( 'Select font that will replace Lato font site-wide', 'conrad' ),
                        'google'    => true, 'text-align'=> false, 'subsets'   => false,'color' => false,'font-weight' => false,'font-style' => false, 'font-size' => false,'line-height' => false,
                        'all_styles'=>true,
                        'default'   => array(
                            'google'      => true,
                            'font-family'   => '',
                        ),
                    ),
                    array(
                        'id'        => 'font_opensans',
                        'type'      => 'typography',
                        'title'     => esc_html__( 'Replace Open Sans font with this one:', 'conrad' ),
                        'subtitle'  => esc_html__( 'Select font that will replace Open Sans font site-wide', 'conrad' ),
                        'google'    => true, 'text-align'=> false, 'subsets'   => false,'color' => false,'font-weight' => false,'font-style' => false, 'font-size' => false,'line-height' => false,
                        'all_styles'=>true,
                        'default'   => array(
                            'google'      => true,
                            'font-family'   => '',
                        ),
                    ),
                    array(
                        'id'        => 'fwp_gmap_key',
                        'type'      => 'text',
                        'title'     => esc_html__( 'Google Maps API Key', 'conrad' ),
                        'subtitle'  => esc_html__( '<a href="https://www.youtube.com/watch?v=-UCHsqxBqwY" target="_blank">How to generate your api key ?</a>', 'conrad' ),
                        'default'   => ''
                    )
                )
            );

              $this->sections[] = array(
                'icon'      => 'el-icon-bookmark',
                'title'     => esc_html__( 'Header', 'conrad' ),
                'fields'    => array(
                        array(
                        'id'        => 'fwp_text_logo',
                        'type'      => 'text',
                        'title'     => esc_html__( 'Logo Text', 'conrad' ),
                        'subtitle'  => esc_html__( 'Here you can set a text as site logo. Default: Conrad ', 'conrad' ),
                        'default'   => 'Conrad',
                        'required'  => array( 'fwp_logo', '=', '' )
                    ),
                    array(
                        'id'        => 'fwp_text_logo_font',
                        'type'      => 'typography',
                        'title'     => esc_html__( 'Logo Font Family', 'conrad' ),
                        'subtitle'  => esc_html__( 'Select font family size and color for logo text', 'conrad' ),
                        'google'    => true, 'text-align'=> false, 'subsets'   => false, 'color' => true, 'font-weight' => false,'font-style' => false, 'font-size' => true,'line-height' => false, 'all_styles '=> true,
                        'units'     => 'px',
                        'output'    => array('.header .header-inner .logo > a > span'),
                        'required'  => array( 'fwp_logo', '=', '' )
                    ),
                    array(
                        'id'        => 'fwp_text_logo_color_hover',
                        'type'      => 'color',
                        'title'     => esc_html__( 'Text Logo Color on Hover', 'conrad' ),
                        'subtitle'  => esc_html__( 'Select color for logo text on mouse hover', 'conrad' ),
                        'output'    => array('.header .header-inner .logo > a:hover > span'),
                        'default'   => '#5e5e5e',
                        'required'  => array( 'fwp_logo', '=', '' )
                    ),
                    array(
                        'id'        => 'fwp_logo',
                        'type'      => 'media',
                        'url'       => true,
                        'title'     => esc_html__( 'Custom Logo', 'conrad' ),
                        'subtitle'  => esc_html__( 'Upload an image that will represent your website`s logo. Recomanded size 100x50px ', 'conrad' )  ,
                        'default'   => ''
                    ),
                    array(
                        'id'       => 'fwp_logo_dimensions',
                        'type'     => 'dimensions',
                        'units'    => array( 'px', 'rem' ),
                        'title'    => esc_html__( 'Custom Logo Dimensions (Width/Height)', 'conrad' ),
                        'subtitle' => esc_html__( 'Set dimensions for custom logo in pixels or rem. For retina logo just upload a image twice normal size.', 'conrad' ),
                        'default'  => array(
                            'Width'   => '100',
                            'Height'  => '50'
                        ),
                    ),
                    array(
                        'id'        => 'fwp_margin_top_logo',
                        'type'           => 'spacing',
                        'output'         => array('#logo_header'),
                        'mode'           => 'margin',
                        'units'          => array('rem', 'px'),
                        'units_extended' => 'false',
                        'right'			 => 'false',
                        'bottom'		 => 'false',
                        'title'          => esc_html__( 'Logo Margin Option', 'conrad' ),
                        'subtitle'       => esc_html__( 'Modify logo margins for all resolutions. ', 'conrad' ),
                        'default'            => array(
                            'margin-top'     => '',
                            'margin-left'    => '',
                            'units'          => '',
                        ),
                        'output'         => array('.logo.logo.logo'),
                    ),
                    array(
                        'id'        => 'fwp_navigation_style2',
                        'type'      => 'select',
                        'title'     => esc_html__( 'Navigation Bar Styling', 'conrad' ),
                        'subtitle'  => esc_html__( 'Choose between few predefined navigation bar color schemes', 'conrad' ),
                        'options'   => array(
                                            '0' => 'Default',
                                            '1' => 'Transparent',
                                            '2' => 'Tall',
                                            '3' => 'Right aligned items',
                                            '4' => 'Sticky After First Section',
                                            ),
                        'default'   => '0',
                    ),

                    array(
                        'id'        => 'fwp_navigation_megamenu',
                        'type'      => 'switch',
                        'title'     => esc_html__( 'Use Megamenu', 'conrad' ),
                        'subtitle'  => esc_html__( 'Use megamenu style submenus', 'conrad' ),
                        'default'   => 0,
                        'on'        => 'Enabled',
                        'off'       => 'Disabled'
                    ),

					array(
                        'id'        => 'nav_bg_color',
                        'type'      => 'color_rgba',
                        'url'       => true,
                        'title'     => esc_html__( 'Navigation background color', 'conrad' ),
                        'subtitle'  => esc_html__( 'Navigation background color default', 'conrad' ),
                        'output'    => array(
                        	                'background-color' => '.header-1-static .header-inner, .header.header-background .header-inner, .header.header-background .navigation .sub-menu, .header.header-background .navigation .mega-sub-menu, .side-navigation-wrapper, .navigation .sub-menu a, .navigation .mega-sub-menu,.navigation .sub-menu',
                        	                'border-color' => '.header.header-background .header-inner'
                                            )
                        ),

					array(
                        'id'        => 'subnav_border_color',
                        'type'      => 'color',
                        'url'       => true,
                        'title'     => esc_html__( 'Submenu border color', 'conrad' ),
                        'output'    => array(
                                            'border-color' => '.header.header-background .navigation .sub-menu, .header.header-background .navigation .mega-sub-menu'
                                            ),
                    ),

					array(
                        'id'        => 'nav_underline_color',
                        'type'      => 'color',
                        'url'       => true,
                        'title'     => esc_html__( 'Navigation animated underline color', 'conrad' ),
                        'output'    => array(
                        	'background-color' => '.navigation ul.mega-sub-menu:before, .navigation ul.sub-menu:before'),
                    ),
					array(
                        'id'        => 'nav_bg_hover_color',
                        'type'      => 'color',
                        'url'       => true,
                        'title'     => esc_html__( 'Navigation submenu background hover color', 'conrad' ),
                        'output'    => array(
                        	                'background-color' => '.navigation .sub-menu li:hover > a, .navigation .mega-sub-menu ul li:hover > a'
                                            ),
                    ),

                    array(
                        'id'        => 'fwp_menu_font',
                        'type'      => 'typography',
                        'title'     => esc_html__( 'Menu items font family', 'conrad' ),
                        'subtitle'  => esc_html__( 'Select font family size and color for menu items', 'conrad' ),
                        'google'    => true, 'text-align'=> false, 'subsets'   => false,'color' => false,'font-weight' => false,'font-style' => false, 'font-size' => true,'line-height' => false,
                        'all_styles'=>true,
                        'units'       =>'px',
                        'output'    => array('body .navigation ul li a, body .navigation ul li a span, .navigation .sub-menu li a, .navigation .mega-sub-menu ul li a'),
                        'default'   => array(
                            'font-family'   => '',
                            'font-weight'   => '',
                            'font-size'     => ''
                        )
                    ),                    
                    array(
                        'id'        => 'fwp_menu_links_color',
                        'type'      => 'link_color',
                        'title'     => esc_html__( 'Menu items color', 'conrad' ),
                        'subtitle'  => esc_html__( 'Select menu items colors for default, hover and active state', 'conrad' ),
                        'google'    => true, 'text-align'=> false, 'subsets'   => false,'color' => false,'font-weight' => false,'font-style' => false, 'font-size' => true,'line-height' => false,
                        'all_styles'=>true,
                        'units'       =>'px',
                        'output'    => array('body header.header nav.navigation > ul li a'),
                        'default'   => array(
                                'regular'  => '',
                                'hover'    => '',
                                'active'   => '',
                                'visited'  => ''
                        ),
                    ),
					array(
                        'id'        => 'fwp_menu_active_link_color',
                        'type'      => 'color',
                        'url'       => true,
                        'title'     => esc_html__( 'Menu item current color', 'conrad' ),
                        'output'    => 'body header.header nav.navigation > ul li.current a',
                    ),
                    array(
                        'id'        => 'fwp_mobile_menu_font',
                        'type'      => 'typography',
                        'title'     => esc_html__( 'Mobile Menu items font family', 'conrad' ),
                        'subtitle'  => esc_html__( 'Select font family size and color for mobile menu items', 'conrad' ),
                        'google'    => true, 'text-align'=> false, 'subsets'   => false,'color' => false,'font-weight' => false,'font-style' => false, 'font-size' => true,'line-height' => false,
                        'all_styles'=>true,
                        'units'       =>'px',
                        'output'    => array('body .side-navigation ul li a, body .side-navigation .sub-menu a'),
                        'default'   => array(
                            'font-family'   => '',
                            'font-weight'   => '',
                            'font-size'     => ''
                        )
                    ),
                    array(
                        'id'        => 'fwp_mobile_menu_links_color',
                        'type'      => 'link_color',
                        'title'     => esc_html__( 'Mobile Menu items color', 'conrad' ),
                        'subtitle'  => esc_html__( 'Select mobile menu items colors for default, hover and active state', 'conrad' ),
                        'google'    => true, 'text-align'=> false, 'subsets'   => false,'color' => false,'font-weight' => false,'font-style' => false, 'font-size' => true,'line-height' => false,
                        'all_styles'=>true,
                        'units'       =>'px',
                        'output'    => array('nav.side-navigation ul li a'),
                        'default'   => array(
                                'regular'  => '',
                                'hover'    => '',
                                'active'   => '',
                                'visited'  => ''
                        )
                    ),
					array(
                        'id'        => 'fwp_menu_active_mob_link_color',
                        'type'      => 'color',
                        'url'       => true,
                        'title'     => esc_html__( 'Mobile Menu item current color', 'conrad' ),
                        'output'    => 'body .side-navigation ul li.current a',
                    ),
                ),
            );

            // Typograply
            $this->sections[] = array(
                'icon' => 'el-icon-font',
                'title' => esc_html__( 'Typography Options', 'conrad' ),
                'fields' => array(
                    array(
                        'id' => 'body_font',
                        'type' => 'typography',
                        'title' => esc_html__( 'Body Font Setting', 'conrad' ),
                        'subtitle' => esc_html__( 'Specify the body font properties.', 'conrad' ),
                        'google' => true,
                        'default' => array(
                            'font-family' => '',
                            'font-size' => '',
                            'line-height' => '',
                            'font-weight' => '',
                            'color' => '',
                        ),
                    ),
                    array(
                        'id' => 'blog_font',
                        'type' => 'typography',
                        'title' => esc_html__( 'Blog Font Setting', 'conrad' ),
                        'subtitle' => esc_html__( 'Specify the body font blog properties.', 'conrad' ),
                        'google' => true,
                        'default' => array(
                            'font-family' => '',
                            'font-size' => '',
                            'line-height' => '',
                            'font-weight' => '',
                            'color' => '',
                        ),
                    ),
                    array(
                        'id' => 'h1_font',
                        'type' => 'typography',
                        'title' => esc_html__( 'Heading 1(H1) Font Setting', 'conrad' ),
                        'subtitle' => esc_html__( 'Specify the H1 tag font properties.', 'conrad' ),
                        'units' => 'em',
                        'google' => true,
                        'default' => array(
                            'font-family' => '',
                            'font-weight' => '',
                            'color' => '',
                        )
                    ),

                    array(
                        'id' => 'h2_font',
                        'type' => 'typography',
                        'title' => esc_html__( 'Heading 2(H2) Font Setting', 'conrad' ),
                        'subtitle' => esc_html__( 'Specify the H2 tag font properties.', 'conrad' ),
                        'google' => true,
                        'default' => array(
                            'font-family' => '',
                            'font-weight' => '',
                            'color' => '',
                        )
                    ),

                    array(
                        'id' => 'h3_font',
                        'type' => 'typography',
                        'title' => esc_html__( 'Heading 3(H3) Font Setting', 'conrad' ),
                        'subtitle' => esc_html__( 'Specify the H3 tag font properties.', 'conrad' ),
                        'google' => true,
                        'default' => array(
                            'font-family' => '',
                            'font-weight' => '',
                            'color' => '',
                        )
                    ),

                    array(
                        'id' => 'h4_font',
                        'type' => 'typography',
                        'title' => esc_html__( 'Heading 4(H4) Font Setting', 'conrad' ),
                        'subtitle' => esc_html__( 'Specify the H4 tag font properties.', 'conrad' ),
                        'google' => true,
                        'default' => array(
                            'font-family' => '',
                            'font-weight' => '',
                            'color' => '',
                        )
                    ),

                    array(
                        'id' => 'h5_font',
                        'type' => 'typography',
                        'title' => esc_html__( 'Heading 5(H5) Font Setting', 'conrad' ),
                        'subtitle' => esc_html__( 'Specify the H5 tag font properties.', 'conrad' ),
                        'google' => true,
                        'default' => array(
                            'font-family' => '',
                            'font-weight' => '',
                            'color' => '',
                        )
                    ),
                    array(
                        'id' => 'h6_font',
                        'type' => 'typography',
                        'title' => esc_html__( 'Heading 6(H6) Font Setting', 'conrad' ),
                        'subtitle' => esc_html__( 'Specify the H6 tag font properties.', 'conrad' ),
                        'google' => true,
                        'default' => array(
                            'font-family' => '',
                            'font-weight' => '',
                            'color' => '',
                        )
                    ),
                )
            );



            $this->sections[] = array(
                'icon'      => 'el-icon-th-list',
                'title'     => esc_html__( 'Blog', 'conrad' ),
                'fields'    => array(
                    array(
                        'id'        => 'opt-info-field2',
                        'type'      => 'info',
                        'title'  => esc_html__( 'Blog settings.', 'conrad' ),
                        'desc'      => esc_html__( 'All settings that affect just blog are present here.', 'conrad' )
                    ),
                    array(
                        'id'        => 'fwp_show_blog_herotitle',
                        'type'      => 'switch',
                        'title'     => esc_html__( 'Show blog title', 'conrad' ),
                        'subtitle'  => esc_html__( 'This setting affects all archive pages (Archive, Category, Author, Tag)', 'conrad' ),
                        'default'   => 1,
                        'on'        => 'Enabled',
                        'off'       => 'Disabled'
                    ),
                    array(
                        'id'        => 'fwp_search_blog_title',
                        'type'      => 'text',
                        'title'     => esc_html__( 'Blog search page title', 'conrad' ),
                        'subtitle'  => esc_html__( 'Title to show on blog search page (shortcodes: :TEXT:)', 'conrad' ),
                        'default'   => 'Blog Search',
                        'required'  => array('fwp_show_blog_herotitle', '=', 1)
                    ),
                    array(
                        'id'        => 'fwp_category_blog_title',
                        'type'      => 'text',
                        'title'     => esc_html__( 'Blog category page title', 'conrad' ),
                        'subtitle'  => esc_html__( 'Title to show on blog category page (shortcodes: :NAME:)', 'conrad' ),
                        'default'   => 'Blog Category',
                        'required'  => array('fwp_show_blog_herotitle', '=', 1)
                    ),
                    array(
                        'id'        => 'fwp_tag_blog_title',
                        'type'      => 'text',
                        'title'     => esc_html__( 'Blog tag page title', 'conrad' ),
                        'subtitle'  => esc_html__( 'Title to show on blog tag page (shortcodes: :NAME:)', 'conrad' ),
                        'default'   => 'Blog Tag',
                        'required'  => array('fwp_show_blog_herotitle', '=', 1)
                    ),
                    array(
                        'id'        => 'fwp_index_blog_title',
                        'type'      => 'text',
                        'title'     => esc_html__( 'Blog index page title', 'conrad' ),
                        'subtitle'  => esc_html__( 'Title to show on blog index page', 'conrad' ),
                        'default'   => 'Blog Index',
                        'required'  => array('fwp_show_blog_herotitle', '=', 1)
                    ),
                    array(
                        'id'        => 'fwp_blog_title_type',
                        'type'      => 'select',
                        'title'     => esc_html__( 'Blog title background type', 'conrad' ),
                        'subtitle'  => esc_html__( 'Choose one of blog title layouts', 'conrad' ),
                        'options'   => array( '' => 'Background Image', 'color' => 'Background Color'),
                        'default'   => ''
                    ),
                    array(
                        'id'        => 'fwp_blog_title_background',
                        'type'      => 'media',
                        'url'       => true,
                        'title'     => esc_html__( 'Blog title background', 'conrad' ),
                        'subtitle'  => esc_html__( 'Background for the title section', 'conrad' )  ,
                        'default'   => '',
                        'required'  => array( array('fwp_show_blog_herotitle', '=', 1), array('fwp_blog_title_type', '=', '') )
                    ),
                    array(
                        'id'        => 'fwp_blog_title_retina_background',
                        'type'      => 'media',
                        'url'       => true,
                        'title'     => esc_html__( 'Blog title retina background', 'conrad' ),
                        'subtitle'  => esc_html__( 'Background for the title section used by retina devices', 'conrad' )  ,
                        'default'   => '',
                        'required'  => array( array('fwp_show_blog_herotitle', '=', 1), array('fwp_blog_title_type', '=', '') )
                    ),
                    array(
                        'id'        => 'fwp_blog_title_bg_color',
                        'type'      => 'background',
                        'url'       => true,
                        'title'     => esc_html__( 'Blog title background', 'conrad' ),
                        'subtitle'  => esc_html__( 'Background color for the title section', 'conrad' )  ,
                        'default'   => '#e62739',
                        'output'    => 'body.blog .intro-title-1',
                        'required'  => array( array('fwp_show_blog_herotitle', '=', 1), array('fwp_blog_title_type', '=', 'color') )
                    ),
                    array(
                        'id'        => 'fwp_blog_author_meta',
                        'type'      => 'switch',
                        'title'     => esc_html__( 'Hide Author Info Box', 'conrad' ),
                        'subtitle'  => esc_html__( 'Shows or hides the post author in blog page.', 'conrad' ),
                        'on'        => 'Yes',
                        'off'       => 'No',
                        'default'   => false,
                    ),
                    array(
                        'id'        => 'fwp_blog_category_meta',
                        'type'      => 'switch',
                        'title'     => esc_html__( 'Hide Category Info Box', 'conrad' ),
                        'subtitle'  => esc_html__( 'Shows or hides the post category in blog page.', 'conrad' ),
                        'on'        => 'Yes',
                        'off'       => 'No',
                        'default'   => false,
                    ),
                    array(
                        'id'        => 'fwp_blog_date_meta',
                        'type'      => 'switch',
                        'title'     => esc_html__( 'Hide Date Info Box', 'conrad' ),
                        'subtitle'  => esc_html__( 'Shows or hides the post date in blog page.', 'conrad' ),
                        'on'        => 'Yes',
                        'off'       => 'No',
                        'default'   => false,
                    ),
                    array(
                        'id'        => 'fwp_blog_comments_meta',
                        'type'      => 'switch',
                        'title'     => esc_html__( 'Hide Comments Info Box', 'conrad' ),
                        'subtitle'  => esc_html__( 'Shows or hides the post comments in blog index page.', 'conrad' ),
                        'on'        => 'Yes',
                        'off'       => 'No',
                        'default'   => false,
                    ),
                    array(
                        'id'        => 'fwp_blog_name_meta',
                        'type'      => 'switch',
                        'title'     => esc_html__( 'Hide Author Name Info Box', 'conrad' ),
                        'subtitle'  => esc_html__( 'Shows or hides the author name in blog page.', 'conrad' ),
                        'on'        => 'Yes',
                        'off'       => 'No',
                        'default'   => false,
                    ),
                    array(
                        'id'        => 'fwp_blog_type',
                        'type'      => 'select',
                        'title'     => esc_html__( 'Blog Layout', 'conrad' ),
                        'subtitle'  => esc_html__( 'Choose one of blog layouts', 'conrad' ),
                        'options'   => array('' => 'Standard', 'masonry' => 'Masonry'),
                        'default'   => ''
                    ),
                    array(
                        'id'        => 'fwp_blog_columns',
                        'type'      => 'select',
                        'title'     => esc_html__( 'Blog Columns', 'conrad' ),
                        'subtitle'  => esc_html__( 'The number of columns', 'conrad' ),
                        'options'   => array( '3' => '3', '4' => '4'),
                        'default'   => '3',
                        'required'  => array('fwp_blog_type', '=', 'masonry')
                    ),
                    array(
                        'id'        => 'fwp_blog_full_width',
                        'type'      => 'button_set',
                        'title'     => esc_html__( 'Blog Width', 'conrad' ),
                        'subtitle'  => esc_html__( 'Blog posts width.', 'conrad' ),
                        'options'   => array( 1 => 'Full Width', 0 => 'Boxed' ),
                        'default'   => true,
                        'required'  => array('fwp_blog_type', '=', 'masonry'),
                    ),
                    array(
                        'id'        => 'fwp_blog_sidebar_pos',
                        'type'      => 'select',
                        'title'     => esc_html__( 'Sidebar position', 'conrad' ),
                        'subtitle'  => esc_html__( 'Choose sidebar position', 'conrad' ),
                        'options'   => array('right'=>'Right',''=>'None','left'=>'Left'),
                        'default'   => 'right'
                    ),
                    array(
                        'id'        => 'fwp_blog_navigation',
                        'type'      => 'select',
                        'title'     => esc_html__( 'Navigation Style On Index', 'conrad' ),
                        'options'   => array(
                                            ''  => 'Inherit',
                                            '0' => 'Default',
                                            '1' => 'Transparent',
                                            '2' => 'Tall',
                                            '3' => 'Right aligned items',
                                            '4' => 'Sticky After First Section',
                                            ),
                        'default'   => ''
                    ),
                )
            );


            $this->sections[] = array(
                'icon'      => 'el-icon-folder',
                'title'     => esc_html__( 'Portfolio', 'conrad' ),
                'fields'    => array(
                    array(
                        'id'        => 'fastwp_portfolio_slug',
                        'type'      => 'text',
                        'title'     => esc_html__( 'Custom Slug', 'conrad' ),
                        'desc'      => esc_html__( 'Use this option in order to change the default portfolio slug (default fwp_portfolio), you need to refresh your permalink page after updating this field.', 'conrad' ),
                        'default'   => 'fwp_portfolio'
                    )
                )
            );



            $this->sections[] = array(
                'icon'      => 'el-icon-inbox',
                'title'     => esc_html__( 'Footer', 'conrad' ),
                'fields'    => array(
                    array(
                        'id'        => 'before_footer_page_id',
                        'type'      => 'select',
                        'title'     => esc_html__( 'Content above footer', 'conrad' ),
                        'subtitle'  => esc_html__( 'Choose one of your pages to be present in all pages above footer area', 'conrad' ),
                        'options'   => FastWP_Conrad_getPostIdAndTitle(),
                    ),
                    array(
                        'id'        => 'footer_override',
                        'type'      => 'switch',
                        'title'     => esc_html__( 'Show this page content as footer', 'conrad' ),
                        'subtitle'  => esc_html__( 'Override default footer with page content.', 'conrad' ),
                        'default'   => 0,
                        'on'        => 'Enabled',
                        'off'       => 'Disabled'
                    ),
                    array(
                        'id'        => 'footer_page_id',
                        'type'      => 'select',
                        'title'     => esc_html__( 'Override footer', 'conrad' ),
                        'subtitle'  => esc_html__( 'Override default footer page with this page content.', 'conrad' ),
                        'options'   => FastWP_Conrad_getPostIdAndTitle(),
                        'required'  => array('footer_override', '=', '1'),
                    ),
                    array(
                        'id'        => 'fwp_footer_back_to_top',
                        'type'      => 'switch',
                        'title'     => esc_html__( 'Show back to top button', 'conrad' ),
                        'subtitle'  => esc_html__( 'Display back to top button in footer area', 'conrad' ),
                        'default'   => '1',
                        'on'        => 'Enabled',
                        'off'       => 'Disabled',
                        'required'  => array('footer_override', '=', '0')
                    ),
                    array(
                        'id'        => 'fwp_footer_back_to_top_text',
                        'type'      => 'text',
                        'title'     => esc_html__( 'Show back to top button', 'conrad' ),
                        'subtitle'  => esc_html__( 'Display back to top button in footer area', 'conrad' ),
                        'default'   => 'Back To Top',
                        'required'  => array('fwp_footer_back_to_top', '=', '1')
                    ),
                    array(
                        'id'        =>'fwp_footer_social_media',
                        'type'      => 'multi_text',
                        'title'     => esc_html__( 'Footer social media', 'conrad' ),
                        'subtitle'  => esc_html__( 'Set any social media networks you want', 'conrad' ),
                        'desc'      => esc_html__( 'Format is LABEL | Icon Class | URL. Example: Facebook | facebook | https://www.facebook.com/', 'conrad' ),
                        'required'  => array('footer_override', '=', '0')
                    ),
                    array(
                        'id'        => 'fwp_footer_social_media_colors',
                        'type'      => 'color',
                        'title'     => esc_html__( 'Social Colors', 'conrad' ),
                        'subtitle'  => esc_html__( 'Select color for social links displayed in footer', 'conrad' ),
                        'output'    => array('.footer .social-list a'),
                        'value'     => '',
                        'default'   => '',
                        'required'  => array('footer_override', '=', '0')
                    ),
                    array(
                        'id'        => 'fwp_footer_social_media_hover',
                        'type'      => 'color',
                        'title'     => esc_html__( 'Social Colors (Hover)', 'conrad' ),
                        'subtitle'  => esc_html__( 'Select color for social links displayed in footer in hover state', 'conrad' ),
                        'output'    => array('.footer .social-list a:hover'),
                        'value'     => '',
                        'default'   => '',
                        'required'  => array('footer_override', '=', '0')
                    ),
                     array(
                        'id'       => 'fwp_footer_background',
                        'type'     => 'background',
                        'title'    => esc_html__( 'Footer Background color', 'conrad' ),
                        'subtitle' => esc_html__( 'Footer background color, etc.', 'conrad' ),
                        'value'    => '#F8F8F8',
                        'default'  => array(
                            'background-color' => '',
                        ),
                        'output'   => '.footer .footer-bottom',
                        'required'  => array('footer_override', '=', '0')
                    ),
                    array(
                        'id'        => 'fwp_menu_slogan',
                        'type'      => 'text',
                        'title'     => esc_html__( 'Copyright text in menu', 'conrad' ),
                        'subtitle'  => esc_html__( 'Display copyright text in mobile menu', 'conrad' ),
                        'default'   => ''
                    ),
                    array(
                        'id'        => 'fwp_footer_slogan',
                        'type'      => 'editor',
                        'title'     => esc_html__( 'Copyright text', 'conrad' ),
                        'subtitle'  => esc_html__( 'Place here your copyright info.', 'conrad' ),
                        'default'   => '<ul>
                                        <li><a href="#" class="fade-location"><span class="icon-right-open-mini"></span>Hire Conrad</a></li>
                                    </ul>',
                        'required'  => array('footer_override', '=', '0'),
                    ),
                ),
            );



            $this->sections[] = array(
                'icon'      => 'el-icon-inbox',
                'title'     => esc_html__( '404 Page', 'conrad' ),
                'fields'    => array(
                    array(
                        'id'        => 'e404_page_hero_skin',
                        'type'      => 'select',
                        'title'     => esc_html__( 'Hero Color', 'conrad' ),
                        'subtitle'  => esc_html__( 'Choose color combination for 404 hero', 'conrad' ),
                        'options'   => array(
                            'bkg-purple color-white' => 'Purple' ,
                            'bkg-turquoise color-white' => 'Turquoise' ,
                            'bkg-green color-white' => 'Green',
                            'bkg-blue color-white' => 'Blue' ,
                            'bkg-navy color-white' => 'Navy' ,
                            'bkg-yellow color-white' => 'Yellow',
                            'bkg-orange color-white' => 'Orange' ,
                            'bkg-orange-light color-white' => 'Light Orange' ,
                            'bkg-red color-white' => 'Red',
                            'bkg-white color-white' => 'White',
                            'bkg-grey color-white' => 'Grey' ,
                            'bkg-grey-light color-white' => 'Grey Light' ,
                            'bkg-grey-ultralight color-white' => 'Grey U-Light' ,
                            'bkg-charcoal color-white' => 'Charcoal',
                            'bkg-charcoal-light color-white' => 'Charcoal Light',
                            'bkg-black color-white' => 'Black',
                            'bkg-base color-white' => 'Base' 
                        ),
                    ),
                    array(
                        'id'        => 'e404_hero_text',
                        'type'      => 'editor',
                        'title'     => esc_html__( '404 hero content', 'conrad' ),
                        'subtitle'  => esc_html__( 'Place here your text for 404 hero.', 'conrad' ),
                        'default'   => '<h1 class="title-xlarge weight-bold horizon" data-animate-in="opacity:0;transX:40px;duration:600ms;delay:0;easing:easeFastSlow;">
                                        404 Not Found
                                    </h1>'
                    ),
                    array(
                        'id'        => 'e404_text',
                        'type'      => 'editor',
                        'title'     => esc_html__( 'Error page content', 'conrad' ),
                        'subtitle'  => esc_html__( 'Place here your text for 404 page.', 'conrad' ),
                        'description' => esc_html__( 'Html content is possible, use [search] shortcode to place a search form.', 'conrad' ),
                        'default'   => '<h2 class="weight-bold mb-30">Bummer, We\'re Totally Lost!</h2><p>Please check the URL for proper spelling or capitalization. Alternatively try to searching below.</p>[search]'
                    ),

                    array(
                        'id'        => 'e404_menu',
                        'type'      => 'switch',
                        'title'     => esc_html__( 'Show menu on 404 page', 'conrad' ),
                        'default'   => 0,
                        'on'        => 'Enabled',
                        'off'       => 'Disabled'
                    ),
                    array(
                        'id'        => 'e404_override',
                        'type'      => 'switch',
                        'title'     => esc_html__( 'Show this page content as 404', 'conrad' ),
                        'subtitle'  => esc_html__( 'Override default 404 page with page content.', 'conrad' ),
                        'default'   => 0,
                        'on'        => 'Enabled',
                        'off'       => 'Disabled'
                    ),
                    array(
                        'id'        => 'e404_page_id',
                        'type'      => 'select',
                        'title'     => esc_html__( 'Override 404', 'conrad' ),
                        'subtitle'  => esc_html__( 'Override default 404 page with this page content.', 'conrad' ),
                        'options'   => FastWP_Conrad_getPostIdAndTitle(),
                        'required'  => array('e404_override', '=', '1'),
                    ),

                ),
            );

        }

        /**

          All the possible arguments for Redux.
          For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments

         * */
        public function setArguments() {

            $theme = wp_get_theme(); // For use with some settings. Not necessary.

            $this->args = array(
                // TYPICAL -> Change these values as you need/desire
                'opt_name'          => 'fastwp_conrad_data',            // This is where your data is stored in the database and also becomes your global variable name.
                'display_name'      => $theme->get('Name'),     // Name that appears at the top of your panel
                'display_version'   => $theme->get('Version'),  // Version that appears at the top of your panel
                'menu_type'         => 'submenu',                  //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                'allow_sub_menu'    => true,                    // Show the sections below the admin menu item or not
                'menu_title'        => esc_html__( 'Theme Options', 'conrad' ),
                'page_title'        => esc_html__( 'Theme Options', 'conrad' ),

                // You will need to generate a Google API key to use this feature.
                // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                'google_api_key' => 'AIzaSyBPVwg6CaFLmKlxYjQu0bJGpxDN1p04S-Q', // Must be defined to add google fonts to the typography module

                'async_typography'  => false,                    // Use a asynchronous font on the front end or font string
                'admin_bar'         => true,                    // Show the panel pages on the admin bar
                'global_variable'   => '',                      // Set a different name for your global variable other than the opt_name
                'dev_mode'          => false,                    // Show the time the page took to load, etc
                'customizer'        => true,                    // Enable basic customizer support

                // OPTIONAL -> Give you extra features
                'page_priority'     => null,                    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                'page_parent'       => 'themes.php',            // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
                'page_permissions'  => 'manage_options',        // Permissions needed to access the options panel.
                'menu_icon'         => '',                      // Specify a custom URL to an icon
                'last_tab'          => '',                      // Force your panel to always open to a specific tab (by id)
                'page_icon'         => 'icon-themes',           // Icon displayed in the admin panel next to your menu_title
                'page_slug'         => '_options',              // Page slug used to denote the panel
                'save_defaults'     => true,                    // On load save the defaults to DB before user clicks save or not
                'default_show'      => false,                   // If true, shows the default value next to each field that is not the default value.
                'default_mark'      => '',                      // What to print by the field's title if the value shown is default. Suggested: *

                // CAREFUL -> These options are for advanced use only
                'transient_time'    => 60 * MINUTE_IN_SECONDS,
                'output'            => true,                    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                'output_tag'        => true,                    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

                // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
                'database'              => '', // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                'show_import_export'    => true, // REMOVE
                'system_info'           => false, // REMOVE

                // HINTS
                'hints' => array(
                    'icon'          => 'icon-question-sign',
                    'icon_position' => 'right',
                    'icon_color'    => 'lightgray',
                    'icon_size'     => 'normal',
                    'tip_style'     => array(
                        'color'         => 'light',
                        'shadow'        => true,
                        'rounded'       => false,
                        'style'         => '',
                    ),
                    'tip_position'  => array(
                        'my' => 'top left',
                        'at' => 'bottom right',
                    ),
                    'tip_effect'    => array(
                        'show'          => array(
                            'effect'        => 'slide',
                            'duration'      => '500',
                            'event'         => 'mouseover',
                        ),
                        'hide'      => array(
                            'effect'    => 'slide',
                            'duration'  => '500',
                            'event'     => 'click mouseleave',
                        ),
                    ),
                )
            );


            // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
            $this->args['share_icons'][] = array(
                'url'   => 'http://twitter.com/fastwp',
                'title' => 'Follow FastWP on Twitter',
                'icon'  => 'el-icon-twitter'
            );
            $this->args['share_icons'][] = array(
                'url'   => 'http://themeforest.net/user/fastwp/portfolio',
                'title' => 'Fastwp Official Page',
                'icon'  => 'el-icon-link'
            );
            $this->args['share_icons'][] = array(
                'url'   => 'mailto:themes@fastwp.net',
                'title' => 'Send an email to FastWP',
                'icon'  => 'el-icon-envelope'
            );
        }

    }

    global $reduxConfig;
    $reduxConfig = new FastWP_Redux_Framework_config();
}

/**
Import custom settings after demo content import
**/
if ( !function_exists( 'wbc_demo_load' ) ) {
    function wbc_demo_load( $demo_active_import , $demo_directory_path ) {
        reset( $demo_active_import );
        $current_key = key( $demo_active_import );

        /* Menu import */
        $wbc_menu_array = array(
            'demo-onepage' => 'One Page Default',
            'demo-multipage' => 'NavMulti'
        );

        if ( isset( $demo_active_import[$current_key]['directory'] ) && !empty( $demo_active_import[$current_key]['directory'] ) && (array_key_exists($demo_active_import[$current_key]['directory'], $wbc_menu_array) || in_array( $demo_active_import[$current_key]['directory'], $wbc_menu_array )) ) {
            $top_menu = get_term_by( 'name', $wbc_menu_array[$demo_active_import[$current_key]['directory']], 'nav_menu' );
			if ( isset( $top_menu->term_id ) ) {
                set_theme_mod( 'nav_menu_locations', array(
                        'primary' => $top_menu->term_id
                    )
                );
            }
        }

        /* Homepage select */
        $wbc_home_pages = array(
            'demo-onepage' => 'One Page',
            'demo-multipage' => 'Home',
        );
        if ( isset( $demo_active_import[$current_key]['directory'] ) && !empty( $demo_active_import[$current_key]['directory'] ) && array_key_exists( $demo_active_import[$current_key]['directory'], $wbc_home_pages ) ) {
            $page = get_page_by_title( $wbc_home_pages[$demo_active_import[$current_key]['directory']] );
            if ( isset( $page->ID ) ) {
                update_option( 'page_on_front', $page->ID );
                update_option( 'show_on_front', 'page' );
            }
        }

        /* Blog page select */
        $wbc_home_pages = array(
            'demo-onepage' => 'Blog',
            'demo-multipage' => 'Blog',
        );
        if ( isset( $demo_active_import[$current_key]['directory'] ) && !empty( $demo_active_import[$current_key]['directory'] ) && array_key_exists( $demo_active_import[$current_key]['directory'], $wbc_home_pages ) ) {
            $page = get_page_by_title( $wbc_home_pages[$demo_active_import[$current_key]['directory']] );
            if ( isset( $page->ID ) ) {
                update_option( 'page_for_posts', $page->ID );
            }
        }
    }
    add_action( 'wbc_importer_after_content_import', 'wbc_demo_load', 10, 2 );
}

/**
Set demo content path
**/

if ( !function_exists( 'wbc_change_demo_directory_path' ) ) {
    function wbc_change_demo_directory_path( $demo_directory_path ) {
        $demo_directory_path = get_template_directory().'/demo-data/';
        return $demo_directory_path;
    }

    add_filter('wbc_importer_dir_path', 'wbc_change_demo_directory_path' );
}



if ( !function_exists( 'wbc_filter_title' ) ) {
    function wbc_filter_title( $title ) {
        return ucfirst( trim( str_replace( "-", " ", str_replace('demo','',$title )) ) );
    }
    add_filter( 'wbc_importer_directory_title', 'wbc_filter_title', 10 );
}