<?php
add_action('init', 						array('fastwp_conrad_actions', 'init'), 10);
add_action('wp_enqueue_scripts',		array('fastwp_conrad_actions', 'enqueue_scripts'));
add_action('admin_enqueue_scripts',		array('fastwp_conrad_actions', 'enqueue_scripts'));
add_action('tgmpa_register', 			array('fastwp_conrad_actions', 'check_required_plugins') );
add_action('attach_footer_info_page', 	array('fastwp_conrad_actions', 'attach_footer_info_page'));
add_action('vc_before_init', 			array('fastwp_conrad_actions', 'set_vc_as_theme'));
add_action('after_setup_theme', 		array('fastwp_conrad_actions', 'fastwp_setup'), 11);	
add_action('_fastwp_no_sections_defined',array('fastwp_conrad_actions', 'no_section_defined'));
add_action('fastwp_conrad_enqueue_script',		array('fastwp_conrad_actions', 'script_loader'),1);
add_action('wp_footer',					array('fastwp_conrad_actions', 'footer'),1);
add_action('wp_footer', 				array('fastwp_conrad_ui', 		'add_custom_css' ), 10 );
add_action('wp_update_nav_menu_item',   array('fastwp_conrad_actions', 'fastwp_navigation_update'),1,3 );


class fastwp_conrad_actions {
	static function init(){
		self::init_visual_composer_blocks();
        self::init_visual_composer_params_blocks();
	}

	static function footer(){
		global $fastwp_conrad_custom_js, $fastwp_conrad_data;
		wp_localize_script('custom', 'fastwp', $fastwp_conrad_custom_js );
        if(isset($fastwp_conrad_data['custom_js']) && !empty($fastwp_conrad_data['custom_js'])){
            wp_add_inline_script('main', $fastwp_conrad_data['custom_js']);
        }
	}


	static function  fastwp_setup(){
	    load_theme_textdomain	('fastwp', get_template_directory() . '/locale');
		add_theme_support		('post-formats', array('quote', 'video', 'image', 'audio','gallery'));
		add_image_size			('portfolio-thumb', 370, 241, true ); // Portfolio 370x241 image (cropped if larger)
		/* Not used */
		$args = array();
		add_theme_support( 'custom-header', $args );
		add_theme_support( 'custom-background', $args );

		// This theme styles the visual editor with editor-style.css to match the theme style.
		add_editor_style();

		// Adds RSS feed links to <head> for posts and comments.
		add_theme_support( 'automatic-feed-links' );

		// This theme uses wp_nav_menu() in one location.
		add_theme_support('menus');
		register_nav_menus( array(
			'primary' => esc_html__( 'Main navigation menu', 'conrad' )
		) );

		add_theme_support( 'title-tag' );

		// This theme uses a custom image size for featured images, displayed on "standard" posts.
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 624, 9999 ); // Unlimited height, soft crop
		
	}

	static function enqueue_scripts(){
		global $wp_plugins;
		if(!is_admin()){
			$admin_bar_uri = get_stylesheet_directory_uri() . '/assets/css/admin-bar.css';
			if(is_admin_bar_showing() && file_exists($admin_bar_uri)){
				wp_enqueue_style('core-admin-bar', $admin_bar_uri);
			}
			$js_composer_url = plugins_url();
			$testURL = ABSPATH . 'wp-content/plugins/js_composer/assets/css/js_composer.css';
			if(file_exists($testURL)){
				wp_enqueue_style('js-composer', $js_composer_url . '/js_composer/assets/css/js_composer.css');
			}
		} else {
			wp_enqueue_style( 'wp-color-picker' );
			wp_enqueue_script( 'wp-color-picker' );

            // load entypo in admin panel
            wp_register_style( 'icomoon_admin', get_template_directory_uri() . '/assets/css/entypo.css', false, '1.0.0' );
            wp_enqueue_style( 'icomoon_admin' );

            // vc editor
            wp_register_style( 'vc_fastwp_admin', get_template_directory_uri() . '/assets/css/admin.css', false, '1.0.0' );
            wp_enqueue_style( 'vc_fastwp_admin' );
		}
	}

	static function check_required_plugins(){
		global $fastwp_conrad_required_plugins;
		if(function_exists('tgmpa') && is_array($fastwp_conrad_required_plugins)){
	    	tgmpa( $fastwp_conrad_required_plugins );
		}
	}

	static function init_visual_composer_blocks(){
		global $fastwp_conrad_visual_composer_blocks;

		/* Visual Composer configuration parser for FastWP Themes */
		if ((class_exists('WPBakeryVisualComposer') || class_exists('Vc_Manager')) && function_exists('vc_map')) {
			if(count($fastwp_conrad_visual_composer_blocks) > 0 && is_array($fastwp_conrad_visual_composer_blocks)){
				foreach($fastwp_conrad_visual_composer_blocks as $vc_block){
					vc_map($vc_block);
				} 
			}
		}
	}

	static function init_visual_composer_params_blocks(){                           
		global $fastwp_conrad_visual_composer_param_blocks;
		/* Visual Composer configuration parser for FastWP Themes */
		if ((class_exists('WPBakeryVisualComposer') || class_exists('Vc_Manager')) && function_exists('vc_map')) {
			if(count($fastwp_conrad_visual_composer_param_blocks) > 0 && is_array($fastwp_conrad_visual_composer_param_blocks)){
				foreach($fastwp_conrad_visual_composer_param_blocks as $vc_param_block){
				    foreach( $vc_param_block['params'] as $param ) {
    					vc_add_param( $vc_param_block['id'], $param );
                    }
				}
			}
		}
	}

	static function attach_footer_info_page(){
		global $post, $fastwp_conrad_data, $fastwp_conrad_custom_shortcode_css;

		if( empty( $fastwp_conrad_data['before_footer_page_id'] ) ) return;

        if( isset( $post->ID ) ) {
            $on_this_page = get_post_meta( $post->ID, 'fwp_prefooter', true );
            if( isset( $on_this_page[0] ) && empty( $on_this_page[0] ) ) return;
        }

		$page_object = get_page( $fastwp_conrad_data['before_footer_page_id'] );
		if( !isset( $page_object->ID ) ) return;
		$fastwp_conrad_custom_shortcode_css .= get_post_meta( $page_object->ID, '_wpb_shortcodes_custom_css', true );

		echo apply_filters('the_content', $page_object->post_content);
	}

	static function set_vc_as_theme() {
		vc_set_as_theme(true);
	}

	static function no_section_defined(){
		echo 'No sections defined !!!';
	}

	static function set_custom_edit_post_columns($columns) {
    	$columns['item_id'] = esc_html__( 'Item ID', 'conrad' );
	   	return $columns;
	}

	static function set_custom_preview_post_columns($columns) {
    	$columns['preview_img'] = esc_html__( 'Preview', 'conrad' );
	   	return $columns;
	}

	static function custom_ID_column( $column, $post_id ) {
	    switch ( $column ) {
	        case 'item_id':
	            echo  $post_id ;
	        break;
            case 'preview_img':
                $image = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'medium' );
                if( isset( $image[0] ) )
                echo '<img src="' . $image[0] . '" style="max-width: 128px; max-height: 128px;" />';
            break;
	    }
	}

	static function script_loader($scripts){
		if(fastwp_conrad_autoload_scripts == true) return;
		$scripts 	= explode(',', $scripts);
		foreach($scripts as $script){
			$handle = sanitize_title($script);
			wp_enqueue_script($handle);
		}
	}

	static function fastwp_navigation_update($menu_id, $menu_item_db_id, $args){
		if(isset($args['menu-item-menuicon_selected']))
			update_post_meta( $menu_item_db_id, '_menu_item_menuicon_selected', sanitize_key($args['menu-item-menuicon_selected']) );
		if(isset($args['menu-item-menuicon']))
			update_post_meta( $menu_item_db_id, '_menu_item_menuicon', sanitize_key($args['menu-item-menuicon']) );
		if(isset($args['menu-item-menutype']))
			update_post_meta( $menu_item_db_id, '_menu_item_menutype', sanitize_key($args['menu-item-menutype']) );
	}

}