<?php

class fastwp_conrad_functions {

	/**
	Register theme scripts and load them depending on global settings.
	**/
	static function register_scripts(){
		global $fastwp_conrad_load_scripts;
		$themeUrl 	= (defined('fastwp_conrad_main_theme_url'))? fastwp_conrad_main_theme_url : get_template_directory_uri();
		$deps 			= 'jquery';
		$in_footer		= true;

		//wp_enqueue_script($deps);
		foreach($fastwp_conrad_load_scripts as $script){
			$handle = sanitize_title($script);
			$src 	= sprintf('%s/assets/js/%s.js', $themeUrl, $script);
			if( filter_var( $script, FILTER_VALIDATE_URL ) ) {
				$src = $script;
			}
			wp_register_script( $handle, $src, $deps, '1.0.0', $in_footer );
			if( (boolean) fastwp_conrad_autoload_scripts || $handle == 'timber-master-min'){
				wp_enqueue_script($handle);
			}
		}
	}

	/**
	Register theme styles and load them depending on global settings.
	**/
	static function register_styles(){
		global $fastwp_conrad_load_styles;
		$themeUrl 	= (defined('fastwp_conrad_main_theme_url'))? fastwp_conrad_main_theme_url : get_template_directory_uri();
		$in_footer	= true;
		foreach($fastwp_conrad_load_styles as $style){
			$handle = sanitize_title($style);
			$src 	= sprintf('%s/assets/css/%s.css', $themeUrl, $style);
			if( filter_var( $style, FILTER_VALIDATE_URL ) ) {
				$src = $style;
			} 
			wp_register_style( $handle, $src);
			if(fastwp_conrad_autoload_styles == true ){
				wp_enqueue_style($handle);
			}
		}
	}

	/** 
    Add custom ID column
	**/
	static function add_custom_column(){
		global $fastwp_conrad_custom_posts_with_id;
		foreach( $fastwp_conrad_custom_posts_with_id as $custom_post => $fields ){
			add_filter( 'manage_edit-' . $custom_post . '_columns', array('fastwp_conrad_actions', 'set_custom_edit_post_columns') );
            if( is_array( $fields ) && in_array( 'thumb', $fields ) ) {
			    add_filter( 'manage_edit-' . $custom_post . '_columns', array('fastwp_conrad_actions', 'set_custom_preview_post_columns') );
            }
			add_action( 'manage_' . $custom_post . '_posts_custom_column' , array('fastwp_conrad_actions', 'custom_ID_column'), 10, 2 );
		}
	}
	
}

add_action('init', array('fastwp_conrad_functions', 'add_custom_column'));
add_action('wp_enqueue_scripts', array('fastwp_conrad_functions', 'register_styles'));
add_action('wp_enqueue_scripts', array('fastwp_conrad_functions', 'register_scripts'));