<?php
if(!class_exists('fastwp_conrad_megamenu')){
	class fastwp_conrad_megamenu {
		function __construct(){
			$this->skipContentItems = false;
			$this->ignoreParents = true;
		}

		function set_skip_content($value = false){
			$this->skipContentItems = $value;
		}

		function set_ignore_parents($value = false){
			$this->ignoreParents = $value;
		}

		function megamenu($echo = true, $menuid = 0, $ignoreParents = true){
			$locations = get_nav_menu_locations();
			if(!isset($locations['primary'])){
				return;
			}
			$this->set_ignore_parents($ignoreParents);

			$menu_id = ($menuid != 0)? $menuid : $locations['primary'];
			$menuItems = wp_get_nav_menu_items($menu = get_term( $menu_id, 'nav_menu' ), array('depth'=>1));

			$currentParent = 0;
			do_action('fastwp_conrad_enqueue_script', 'template-functions');
			if($echo === true) {
				echo $this->recursiveItemCreation($menuItems, $currentParent);
			} 
			else {
				return $this->recursiveItemCreation($menuItems, $currentParent);
			}
		}

		function getItemTemplate(){
			return '<li class="fwp-navigation__item  %s" %s>%s</li>';
		}

		function getAnchorTemplate(){
			return '<a href="%s" class="fwp-navigation__link  %s" %s>%s</a>';
		}

        /************
        TODO: Add support for text on menu
        *************/
		function recursiveItemCreation($items, $parent, $isMega = false){
			$pageTemplate	= (is_page() || is_single())? basename(get_page_template()) : '';
			$itemsToOutput 	= array(array());
			$arrayIndex 	= 0;
			$anchorTemplate = $this->getAnchorTemplate();
			$itemTemplate 	= $this->getItemTemplate();

			foreach($items as $item){

				if(intval($item->menu_item_parent) != intval($parent))
					continue;
				$_arrayIndex = $arrayIndex;
				$extra = '';
				
				if($this->ignoreParents == true && in_array('column-break', $item->classes)){
					$arrayIndex++;
					$isMega = true;
				}

				$hasContent = false;
				$content = '';
				if(in_array('inline-content', $item->classes) || in_array('inline-content-parent', $item->classes) || in_array('ignore-on-mobile', $item->classes)){
					if($this->skipContentItems){
						continue;
					}
					$hasContent = true;
					$page = get_page($item->object_id);
					$content = (isset($page->post_content) && !empty($page->post_content))? apply_filters('the_content', $page->post_content) : '';
				}

				$type 				= get_post_meta( $item->ID, '_menu_item_menutype', true );
				$onepage_separator 	= false;
				$onepage_section 	= false;
				if( isset( $type ) && $type != '' && $type != 'page' ) {
					$onepage_section= true;
					if( $type == 'separator' ) {
						$onepage_separator = true;
					}
				}
				if( $onepage_separator === true ) continue;

				$href 	 = ( $onepage_section == true && ( !isset( $item->object ) || $item->object != 'custom' ) ) ? sprintf( '#%s', FastWP::getMenuSectionId( $item ) ) : $item->url;
				if($href != $item->url){
					if($pageTemplate != 'template-one-page.php'){
						$href 	= site_url() . $href;
					}
				}
				$css_class = ( intval( $item->object_id ) === intval( fastwp_conrad_utils::get_current_object_id() ) ) ? 'current-menu-item ' : '';

				$css_class .= is_front_page() && ( $onepage_section == true && ( !isset( $item->object ) || $item->object != 'custom' ) ) ? ' scroll-link': '';
				if($this->ignoreParents == false) {
					$css_class = $this->getParentClass($css_class, $items, $item);
				}
				$itemsToOutput[$_arrayIndex][] =  ($hasContent && $content != '')? $content : sprintf($anchorTemplate, $href, trim( $css_class ), $extra, $item->title) . $this->recursiveItemCreation( $items, $item->ID, $isMega );
			}
			
			// If no submenu item is found return false
			if(count($itemsToOutput) == 1 && count($itemsToOutput[0]) == 0)
				return false;

			$columnCount = count($itemsToOutput);
			if($columnCount > 5){
				self::warn('More than 5 columns for menu items are not allowed');
				return;
			}
			$submenu_class = ($parent != 0 && $isMega == false)? 'sub-menu' : '';
			$parent_item_class = '';
			switch ($columnCount) {
				case 5:
				case 4:
				case 3:
				case 2:
					$submenu_class = 'mega-sub-menu nav__column-count-' . $columnCount;
					break;

				default:
					
					break;
			}
			$finalItems = '';
			$finalItems = sprintf('<ul class="%s">', $submenu_class);

			foreach($itemsToOutput as $column){
				foreach ($column as $item) {
					preg_match('|current-menu-item|ims', $item, $out);
					$class = (count($out) == 1)? sprintf('class="%s"', 'current') : '';
					$finalItems .= sprintf('<li %s>%s</li>
						', $class, $item);
				}
			}
			$finalItems .= '</ul>';
			
			$output = $finalItems;
			return $output;
		}

		static public function warn($message){
			/* TODO: Improve this implementation */
			echo esc_html ( $message );
		}

		function getParentClass($css_class, $items, $item){
			// var_dump(array($item->object_id, $item->ID));
			$current_item_id = $item->ID;
			$found = false;
			foreach ($items as $key => $value) {
				if($found == true){
					continue;
				}
				if($value->menu_item_parent == $current_item_id){
					$found = true;
				}
			}
			if($found === true){
				return $css_class . ' contains-sub-menu ';
			} else {
				return $css_class;
			}
		}
	}
}